@@ -1,5 +1,3 @@
-( cd opt/kde/lib ; rm -rf libaktion.so )
-( cd opt/kde/lib ; ln -sf libaktion.so.1.0.0 libaktion.so )
 ( cd opt/kde/lib ; rm -rf libworkman.so )
 ( cd opt/kde/lib ; ln -sf libworkman.so.1.4.3 libworkman.so )
 ( cd opt/kde/lib ; rm -rf libartsgui.so.0 )
@@ -44,8 +42,6 @@
 ( cd opt/kde/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so.0 )
 ( cd opt/kde/lib ; rm -rf libarts_splay.so )
 ( cd opt/kde/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so )
-( cd opt/kde/lib ; rm -rf libaktion.so.1 )
-( cd opt/kde/lib ; ln -sf libaktion.so.1.0.0 libaktion.so.1 )
 ( cd opt/kde/lib ; rm -rf libartsgui.so )
 ( cd opt/kde/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so )
 ( cd opt/kde/lib ; rm -rf libartsgui_kde.so.0 )
